@@ -12,7 +12,7 @@ use strictures 2;
 use namespace::clean;
 
 use Exporter 'import';
-our @EXPORT_OK = qw(
+our @EXPORT = qw(
     get_score
     b
     c
@@ -27,7 +27,7 @@ our @EXPORT_OK = qw(
     x
 );
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 =head1 NAME
 
@@ -35,7 +35,7 @@ idi - Easy Command-line MIDI
 
 =head1 SYNOPSIS
 
-  perl -Midi -E'x(qw(c1 f o5); n(qw(qn Cs)); n("F"); n("Ds"); n(qw(hn Gs_d1)); w()'
+  perl -Midi -E'x(qw(c1 f o5)); n(qw(qn Cs)); n("F"); n("Ds"); n(qw(hn Gs_d1)); w()'
 
   timidity idi.mid
 
